#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : tql-App.
# @File         : sklearn.lgb.ctr
# @Time         : 2019-08-29 18:05
# @Author       : yuanjie
# @Email        : yuanjie@xiaomi.com
# @Software     : PyCharm
# @Description  :


def feature_transform(**kwargs):
    """

    :param kwargs:
    :return: 返回二维数组 model.predict(X)
    """

    return [[kwargs.get('x', 1)]]



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : tql-App.
# @File         : demo
# @Time         : 2019-11-13 15:44
# @Author       : yuanjie
# @Email        : yuanjie@xiaomi.com
# @Software     : PyCharm
# @Description  : 

import asyncio
from datetime import datetime, time, timedelta

from sanic import Sanic

from sanic_scheduler import SanicScheduler, task


app = Sanic()
scheduler = SanicScheduler(app)


@task(timedelta(seconds=30))
def hello(app):
    """Runs the function every 30 seconds."""
    print("Hello, {0}".format(app), datetime.now())


@task(timedelta(hours=1), time(hour=1, minute=30))
async def foo_bar(_):
    """Runs the function every 1 hours after 1:30."""
    print("Foo", datetime.now())
    await asyncio.sleep(1)
    print("Bar")


@task(timedelta(minutes=2), timedelta(seconds=10))
def baz(_):
    """Runs the function every 2 minutes after 10 seconds."""
    print("Baz", datetime.now())


@task(start=timedelta(seconds=10))
def another(_):
    """Run the function after 10 seconds once."""
    print("another", datetime.now())


if __name__ == "__main__":
    app.run(host='127.0.0.1', port=5000, debug=True, workers=4)



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : tql-App.
# @File         : app
# @Time         : 2019-08-15 13:47
# @Author       : yuanjie
# @Email        : yuanjie@xiaomi.com
# @Software     : PyCharm
# @Description  : 

from sanic import Sanic
from sanic import response
from iapp.utils import Templates

app = Sanic(__name__)

templates_map = Templates().load()


def get_apps(k, v):
    @app.route(f'/{k}')
    async def index(request):
        _ = await v.render_async(body="body")
        return response.html(_)

for k, v in templates_map.items():
    get_apps(k, v)


app.run()



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : tql-App.
# @File         : app_run
# @Time         : 2019-08-30 13:51
# @Author       : yuanjie
# @Email        : yuanjie@xiaomi.com
# @Software     : PyCharm
# @Description  : 
"""
通过在main文件
"""

from iapp import App


import os
os.sys.path.append("/Users/yuanjie/Desktop/Projects/Python/tql-App/examples/fds/models")

print(__import__('sklearn_lr_demo').feature_transform)



# app = App()
# app.add_route('/cmd', cmd)
# app.run()


